<!-- contains Cornell logo and sponsor statement -->
<div class="attribution level is-marginless" role="banner">
  <div class="level-left">
    <a class="level-item" href="{{ url_for('library') }}"><img src="{{ url_for('base.static', filename='images/CUL-reduced-white-SMALL.svg') }}" alt="Cornell University Library" width="300" aria-label="logo" /></a>
  </div>
  <div class="level-right"><p class="sponsors level-item is-marginless"><a href="{{ url_for('acknowledgment') }}">We gratefully acknowledge support from<br /> the Simons Foundation and member institutions</a></p></div>
</div>
<!-- contains arXiv identity and search bar -->
<div class="identity level is-marginless">
  <div class="level-left">
    <h1 class="level-item"><a href="{{ url_for('home') }}" aria-label="arxiv-logo">arXiv.org</a></h1>
  </div>
  {{ macros.compactsearch('level-right') }}
</div> <!-- closes identity -->

<div class="container">
    <div class="user-tools is-size-7 has-text-right has-text-weight-bold" role="navigation" aria-label="User menu">
      {% if request.session and request.session.user %}Logged in as <span class="has-text-weight-bold">{{ request.session.user.username }}</span> | <a href="{{ url_for('account') }}">My Account</a> | <a href="{{ url_for('logout') }}">Logout</a>{% else %}<a href="{{ url_for('login') }}">Login</a>{% endif %}
    </div>
</div>

<div class="container notifications" role=alert>
    {% with messages = get_flashed_messages(with_categories=true) %}
      {% if messages %}
        {% for category, message in messages %}
          <div class="notification is-{{ category }}">
            {% if message.dismissable %}<button class="delete notification-dismiss"></button>{% endif %}
            {% if message.title %}<h2 class="has-text-weight-bold">{{ message.title }}</h2>{% endif %}
            <p class="is-size-7">{{ message.message }}</p>
          </div>
        {% endfor %}

      {% endif %}
    {% endwith %}
</div>
