/** All of the custom styles for arXiv-NG - related to specific graphical style rather than overrides of Bulma - are placed here. **/

/* line-height property here sets vertical alignment to center */
header h1
  font-size: 2em
  font-weight: bold
  padding: .25em 0 .5em

footer
  background-color: $grey
  color: #fff
  padding: .5em 2em .75em 2em
  a
    color: #fff
    border-bottom: 1px solid transparent
    &:hover,
    &:active
      border-bottom: 1px dotted #fff
      background-color: $grey-light

.nav-spaced
  line-height: 2

.content
  h1
    font-size: 1.75em

.attribution
  align-items: center
  background-color: $cul-gray
  color: #fff
  line-height: 1
  .level-left
    padding: .25em

.identity
  background-color: $cul-red
  color: #fff
  padding: 0 .75em
  a
    color: #fff
    border-bottom: 1px solid transparent
    &:visited
      color: #fff
    &:hover
      border-bottom: 1px dotted #fff
      color: #fff

.logo
  height: 45px
  margin: .2em
  vertical-align: middle

.button.is-cul-darker
  background-color: $cul-red-darker
  color: $white
  border-color: transparent

.sponsors
  font-size: .9em
  font-weight: 600
  line-height: 1.3
  margin: 4px
  padding-right: .75em
  text-align: right
  a
    color: #fff
    &:visited
      color: #fff
    &:hover
      background-color: $grey-light
      color: #fff

.status-code
  background-color: $black
  color: #00FF00
  font-size: 16em
  font-family: 'Courier', monospace
  font-weight: bold
  width: max-content
  line-height: 1em
  padding: .1em .25em
  margin-left: auto !important
  margin-right: auto !important

.beta
  &::after
    content: '\03b2'
    color: $grey-lighter
    font-size: 25em
    position: absolute
    top: 0
    left: 0
    line-height: .75em
    font-family: serif
    z-index: -10

.is-monospace
  font-family: monospace

/* specific styles for search lists with classic dl/dt/dd structure and classes */
.list-identifier
  font-weight: 600

.list-title
  font-size: 1.25em
  font-weight: 600

dt
  margin-top: 1em

/* utility styles for forms */
.fieldset
  border: 1px solid $grey-lighter
  border-radius: $radius-small
  padding: .5em 1em 1em 1em
  margin: 1em 0

.fieldset.is-warning
  border: 1px solid #d47500

.fieldset.is-danger
  border: 1px solid #cd0200

.legend
  font-weight: $weight-semibold
  background-color: inherit
  padding: 0 .5em
  margin-left: -.5em

.is-baseline
  align-items: baseline

.is-centered-vertically
  margin-top: auto !important
  margin-bottom: auto !important

.hidden-label
  border: 0
  clip: rect(0,0,0,0)
  height: 1px
  width: 0
  margin: -1px
  overflow: hidden
  padding: 0
  position: absolute

.is-datefield
  max-width: 8rem

.is-short-field
  max-width: 25rem

/* table and file tree styles */

.is-subdirectory
  margin-left: 2em

tr.is-danger
  background-color: #fff5f5
  color: #970503
  border: 1px solid #cd0200
  td
    border-color: #cd0200
    &:first-child
      padding-left: 2em
      &:before
        content: '\f071'
        font-family: 'FontAwesome'
        color: #cd0200
        position: absolute
        left: .5em

tr.is-warning
  background-color: #fffaf5
  color: #5d3605
  border: 1px solid #d47500
  td
    border-color: #d47500
    &:first-child
      padding-left: 2em
      &:before
        content: '\f071'
        font-family: 'FontAwesome'
        color: #d47500
        position: absolute
        left: .5em

/* whitespace styles */
.breathe-vertical
  margin-top: 4rem
  margin-bottom: 4rem

.breathe-horizontal
  @media screen and (min-width: 769px)
    margin-left: 4rem !important
    margin-right: 4rem !important
  @media screen and (min-width: 980px)
    margin-left: 6rem !important
    margin-right: 6rem !important

/* pagination styles */
.pagination
  margin-top: 3rem
  margin-bottom: 2rem

.pagination-list
  margin: 0 !important

.pagination-list li
  list-style: none

.pagination-list li + li // fixes override from content li + li
  margin: 0

/* flash notifications */

.notifications
  margin-top: .3em
  width: 60%

.notification
  margin-left: auto
  margin-right: auto
  margin-bottom: .3em !important
